@@ -3,6 +3,7 @@ import sys
 import requests
 import tarfile
 import tempfile
+import time
 import backstage
 from backstage.venue import use_venue
 from backstage.venue import Venue
@@ -37,7 +38,6 @@ class Act():
         except IOError:
             print 'Could not update, permission denied.'
             return
-        time.sleep(5) #give the new port time to bind.
         self.get_uwsgi_port()
         return
 
@@ -87,11 +87,19 @@ class Act():
 
     def get_uwsgi_port(self):
         """Get the uwsgi port using lsof.  Requires that lsof and fuser be suid root"""
-        fullport = uwsgi_portsniffer.port_from_lsof(self.vassal_file)
-        try:
-            self.uwsgi_ip, self.uwsgi_port = fullport.split(':')
-        except:
-            self.uwsgi_ip = None; self.uwsgi_port = None
+        self.uwsgi_ip = None; self.uwsgi_port = None
+        timeout = 10
+        nap = 2
+        starttime = time.time()
+        elapsed = 0
+        while not valid and elapsed < timeout:
+            try:
+                fullport = uwsgi_portsniffer.port_from_lsof(self.vassal_file)
+                self.uwsgi_ip, self.uwsgi_port = fullport.split(':')
+                break
+            except:
+                time.sleep(nap)
+                elapsed = time.time() - starttime
         return
 
 
